===============
Builtin Plugins
===============

.. toctree::
   :maxdepth: 2

   plugins/discovery
   plugins/functions
   plugins/generators
   plugins/parameters
   plugins/testcases
   plugins/doctests
   plugins/result
   plugins/buffer
   plugins/debugger
   plugins/failfast
   plugins/logcapture
   plugins/outcomes

   plugins/collect
   plugins/testid

   plugins/printhooks
   plugins/prof



